==> classpath-0.19.tar.gz: classpath-0.19/org/omg/PortableInterceptor/ObjectReferenceFactoryOperations.java <==
/* ObjectReferenceFactoryOperations.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor;

import org.omg.CORBA.portable.ValueBase;

/**
 * Defines the operations, applicable to the ObjectReferenceFactory.
 *
 * @since 1.5
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public interface ObjectReferenceFactoryOperations
  extends ValueBase
{
  /**
   * Create an object with the given repository and object ids. This interface
   * does not specify where and how the returned object must be connected and
   * activated.
   *
   * @param repositoryId the repository id of the object being created, defines
   * the type of the object.
   *
   * @param objectId the byte array, defining the identity of the object.
   */
  org.omg.CORBA.Object make_object(String repositoryId, byte[] objectId);
}

==> classpath-0.20.tar.gz: classpath-0.20/org/omg/PortableInterceptor/ObjectReferenceFactoryOperations.java <==
/* ObjectReferenceFactoryOperations.java --
   Copyright (C) 2005 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package org.omg.PortableInterceptor;

import org.omg.CORBA.portable.ValueBase;

/**
 * Defines the operations, applicable to the ObjectReferenceFactory.
 *
 * @since 1.5
 *
 * @author Audrius Meskauskas, Lithuania (AudriusA@Bioinformatics.org)
 */
public interface ObjectReferenceFactoryOperations
  extends ValueBase
{
  /**
   * Create an object with the given repository and object ids. This interface
   * does not specify where and how the returned object must be connected and
   * activated. The derived {@link ObjectReferenceTemplate} interface assumes
   * the the object must be connected to the POA that is specific to that
   * template (name can be obtained).
   * 
   * If the object with this objectId already exists in the given context, it is
   * found and returned; the new object is <i>not</i> created.
   * 
   * @param repositoryId the repository id of the object being created, defines
   * the type of the object.
   * 
   * @param objectId the byte array, defining the identity of the object.
   */
  org.omg.CORBA.Object make_object(String repositoryId, byte[] objectId);
}
